Library (Sphinx theme)
======================

Library is a minimal typography-centric theme for the `Sphinx
<http://sphinx-doc.org>`_ documentation system, designed to read like a good
book. Features include:

* Publisher-selectable typeface stacks.

* User-selectable light/sepia/dark reading modes.

* Mobile-friendly responsive design.

See what it looks like, options, and design notes in the `Documentation
<https://vsalvino.github.io/sphinx-library>`_.

`Source Code <https://github.com/vsalvino/sphinx-library>`_ |
`Documentation <https://vsalvino.github.io/sphinx-library>`_ |
`PyPI <https://pypi.org/project/sphinx-library/>`_
